@@ -369,6 +369,11 @@ impl BuildOptions {
                             implmentation_name: "cpython".to_string(),
                             soabi: None,
                         }])
+                    } else if let Some(config_file) = env::var_os("PYO3_CONFIG_FILE") {
+                        let interpreter_config =
+                            InterpreterConfig::from_pyo3_config(config_file.as_ref(), target)
+                                .context("Invalid PYO3_CONFIG_FILE")?;
+                        Ok(vec![PythonInterpreter::from_config(interpreter_config)])
                     } else if let Some(interp) = interpreters.get(0) {
                         println!("🐍 Using {interp} to generate to link bindings (With abi3, an interpreter is only required on windows)");
                         Ok(interpreters)
@@ -517,7 +522,7 @@ impl BuildOptions {
 
         let mut universal2 = self.universal2;
         if universal2 {
-            eprintln!("⚠️  Warning: `--universal2` is deprecated, use `--target univeral2-apple-darwin` instead");
+            eprintln!("⚠️  Warning: `--universal2` is deprecated, use `--target universal2-apple-darwin` instead");
         } else if target_triple.as_deref() == Some("universal2-apple-darwin") {
             universal2 = true;
             target_triple = None;
