@@ -27,8 +27,6 @@ use std::path::{Path, PathBuf};
 use std::process::{Command, Output};
 use std::str;
 use tempfile::{tempdir, TempDir};
-use time::macros::datetime;
-use time::OffsetDateTime;
 use tracing::debug;
 use zip::{self, DateTime, ZipWriter};
 
@@ -331,11 +329,14 @@ impl WheelWriter {
     /// Note that the earliest timestamp a zip file can represent is 1980-01-01
     fn mtime(&self) -> Result<DateTime> {
         let epoch: i64 = env::var("SOURCE_DATE_EPOCH")?.parse()?;
-        let dt = OffsetDateTime::from_unix_timestamp(epoch)?;
-        let min_dt = datetime!(1980-01-01 0:00 UTC);
+        let dt = time::OffsetDateTime::from_unix_timestamp(epoch)?;
+        let min_dt = time::Date::from_calendar_date(1980, time::Month::January, 1)
+            .unwrap()
+            .midnight()
+            .assume_offset(time::UtcOffset::UTC);
         let dt = dt.max(min_dt);
 
-        let dt = DateTime::from_time(dt).map_err(|_| anyhow!("Failed to build zip DateTime"))?;
+        let dt = DateTime::try_from(dt).map_err(|_| anyhow!("Failed to build zip DateTime"))?;
         Ok(dt)
     }
 
@@ -711,22 +712,28 @@ pub fn write_bindings_module(
     module_name: &str,
     artifact: &Path,
     python_interpreter: Option<&PythonInterpreter>,
+    is_abi3: bool,
     target: &Target,
     editable: bool,
     pyproject_toml: Option<&PyProjectToml>,
 ) -> Result<()> {
     let ext_name = &project_layout.extension_name;
-    let so_filename = match python_interpreter {
-        Some(python_interpreter) => python_interpreter.get_library_name(ext_name),
-        // abi3
-        None => {
-            if target.is_unix() {
-                format!("{ext_name}.abi3.so")
-            } else {
+    let so_filename = if is_abi3 {
+        if target.is_unix() {
+            format!("{ext_name}.abi3.so")
+        } else {
+            match python_interpreter {
+                Some(python_interpreter) if python_interpreter.is_windows_debug() => {
+                    format!("{ext_name}_d.pyd")
+                }
                 // Apparently there is no tag for abi3 on windows
-                format!("{ext_name}.pyd")
+                _ => format!("{ext_name}.pyd"),
             }
         }
+    } else {
+        let python_interpreter =
+            python_interpreter.expect("A python interpreter is required for non-abi3 build");
+        python_interpreter.get_library_name(ext_name)
     };
 
     if !editable {
